oerplib.rpc
===========

.. automodule:: oerplib.rpc

.. autoclass:: oerplib.rpc.Connector
    :members:

XML-RPC and Net-RPC connectors
''''''''''''''''''''''''''''''

.. autoclass:: oerplib.rpc.ConnectorXMLRPC
    :members:

.. autoclass:: oerplib.rpc.ConnectorXMLRPCSSL
    :members:

.. autoclass:: oerplib.rpc.ConnectorNetRPC
    :members:

.. automethod:: oerplib.rpc.get_connector

JSON-RPC connectors **(New in version 0.8)**
''''''''''''''''''''''''''''''''''''''''''''

.. warning::

    The support of JSON-RPC is still in the experimental stage.

.. autoclass:: oerplib.rpc.ConnectorJSONRPC
    :members:

.. autoclass:: oerplib.rpc.ConnectorJSONRPCSSL
    :members:
